@@ -1,6 +1,6 @@
 ;;; color-theme-ahungry.el --- Ahungry color theme for Emacs.
 
-;; Copyright (C) 2015  Free Software Foundation, Inc.
+;; Copyright (C) 2015-2017  Free Software Foundation, Inc.
 
 ;; Author: Matthew Carter <m@ahungry.com>
 ;; Maintainer: Matthew Carter <m@ahungry.com>
@@ -154,7 +154,7 @@
      (org-level-4 ((t (:bold nil :foreground "#f68585" :height 1.0))))
      (org-date ((t (:underline t :foreground "#ff0066"))))
      (org-footnote  ((t (:underline t :foreground "#ff0066"))))
-     (org-link ((t (:foreground "skyblue2" :background "#2e3436"))))
+     (org-link ((t (:background "#111111" :foreground "#ff0099"))))
      (org-special-keyword ((t (:foreground "#cc0033"))))
      (org-verbatim ((t (:foreground "#cc6600" :underline t :slant italic))))
      (org-block ((t (:foreground "#999999"))))
@@ -182,6 +182,29 @@
      (helm-selection ((t (:foreground "#ff0099" :italic t :bold t :background "#f2e997"))))
      (helm-match ((t (:foreground "gold1"))))
      (helm-visible-mark ((t (:background "#f2e997" :foreground "#ff0099" :bold nil :italic nil))))
+
+     (erc-nick-default-face ((t (:foreground "#ff0099"))))
+     (erc-current-nick-face ((t (:foreground "#0099ff"))))
+     (erc-input-face ((t (:foreground "#0099ff"))))
+     (erc-prompt-face ((t (:background nil :foreground "#666666" :bold t :italic t))))
+     (erc-timestamp-face ((t (:background nil :foreground "#666666" :bold nil :italic t))))
+     (jabber-chat-prompt-foreign ((t (:foreground "#ff0099"))))
+     (jabber-chat-prompt-local ((t (:foreground "#0099ff"))))
+     (jabber-rare-time-face ((t (:foreground "#666666" :bold nil :italic t))))
+     (eshell-prompt ((t (:foreground "#0099ff"))))
+     (info-menu-header ((t (:foreground "#0099ff" :bold t :underline t))))
+     (info-header-xref ((t (:foreground "#0099ff"))))
+     (info-header-node ((t (:foreground "#ff0099" :bold t :italic t))))
+     (info-menu-star ((t (:foreground "#0099ff" :bold t))))
+     (info-xref-visited ((t (:foreground "#999999"))))
+     (info-xref ((t (:foreground "#0099ff"))))
+     (info-node ((t (:foreground "#ff0099"))))
+     (info-title-1 ((t (:foreground "yellow" :bold t))))
+     (info-title-2 ((t (:foreground "#ff0099"))))
+     (realgud-line-number ((t (:foreground "#999999"))))
+     (realgud-overlay-arrow1 ((t (:foreground "#6699ff"))))
+     (realgud-overlay-arrow2 ((t (:foreground "#0099ff"))))
+     (realgud-overlay-arrow3 ((t (:foreground "#00aa99"))))
      )))
 
 (provide 'color-theme-ahungry)
